Learn R Programming

tidyEmoji (version 0.1.1)

emoji_categorize: Categorize Emoji Tweets/text based on Emoji category

Description

Users can use emoji_categorize to see the all the categories each Emoji Tweet has. The function preserves the input data structure, and the only change is it adds an extra column with information about Emoji category separated by | if there is more than one category.

Usage

emoji_categorize(tweet_tbl, tweet_text)

Value

A filtered dataframe with the presence of Emoji only, and with an extra column .emoji_category.

Arguments

tweet_tbl

A dataframe/tibble containing tweets/text.

tweet_text

The tweet/text column.

Examples

Run this code
library(dplyr)
data.frame(tweets = c("I love tidyverse \U0001f600\U0001f603\U0001f603",
                      "R is my language! \U0001f601\U0001f606\U0001f605",
                      "This Tweet does not have Emoji!",
                      "Wearing a mask\U0001f637\U0001f637\U0001f637.",
                      "Emoji does not appear in all Tweets",
                      "A flag \U0001f600\U0001f3c1")) %>%
         emoji_categorize(tweets)

Run the code above in your browser using DataLab